@@ -47,7 +47,7 @@ model_urls = {
             'ch_sim': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_server/rec_ench_ppocr_server.tar',
-                'dict_path': './utils/dict/ench_dict.txt',
+                'dict_path': 'utils/dict/ench_dict.txt',
                 
             }
         }
@@ -64,163 +64,163 @@ model_urls = {
             'ch_sim': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ench_ppocr_mobile.tar',
-                'dict_path': './utils/dict/ench_dict.txt',
+                'dict_path': 'utils/dict/ench_dict.txt',
                 
             },
             'en': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_en_number_mobile.tar',
-                'dict_path': './utils/dict/en_dict.txt',
+                'dict_path': 'utils/dict/en_dict.txt',
                 
             },
             'fr': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_french_mobile.tar',
-                'dict_path': './utils/dict/french_dict.txt',
+                'dict_path': 'utils/dict/french_dict.txt',
                 
             },
             'de': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_german_mobile.tar',
-                'dict_path': './utils/dict/german_dict.txt',
+                'dict_path': 'utils/dict/german_dict.txt',
                 
             },
             'ko': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_korean_mobile.tar',
-                'dict_path': './utils/dict/korean_dict.txt',
+                'dict_path': 'utils/dict/korean_dict.txt',
                 
             },
             'ja': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_japan_mobile.tar',
-                'dict_path': './utils/dict/japan_dict.txt',
+                'dict_path': 'utils/dict/japan_dict.txt',
                 
             },
             'ch_tra': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_chinese_cht_mobile.tar',
-                'dict_path': './utils/dict/chinese_cht_dict.txt',
+                'dict_path': 'utils/dict/chinese_cht_dict.txt',
                 
             },
             'it': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_it_mobile.tar',
-                'dict_path': './utils/dict/it_dict.txt',
+                'dict_path': 'utils/dict/it_dict.txt',
                 
             },
             'es': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_xi_mobile.tar',
-                'dict_path': './utils/dict/xi_dict.txt',
+                'dict_path': 'utils/dict/xi_dict.txt',
                 
             },
             'pt': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_pu_mobile.tar',
-                'dict_path': './utils/dict/pu_dict.txt',
+                'dict_path': 'utils/dict/pu_dict.txt',
                 
             },
             'ru': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ru_mobile.tar',
-                'dict_path': './utils/dict/ru_dict.txt',
+                'dict_path': 'utils/dict/ru_dict.txt',
                 
             },
             'ar': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ar_mobile.tar',
-                'dict_path': './utils/dict/ar_dict.txt',
+                'dict_path': 'utils/dict/ar_dict.txt',
                 
             },
             'hi': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_hi_mobile.tar',
-                'dict_path': './utils/dict/hi_dict.txt',
+                'dict_path': 'utils/dict/hi_dict.txt',
                 
             },
             'ug': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ug_mobile.tar',
-                'dict_path': './utils/dict/ug_dict.txt',
+                'dict_path': 'utils/dict/ug_dict.txt',
                 
             },
             'fa': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_fa_mobile.tar',
-                'dict_path': './utils/dict/fa_dict.txt',
+                'dict_path': 'utils/dict/fa_dict.txt',
                 
             },
             'ur': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ur_mobile.tar',
-                'dict_path': './utils/dict/ur_dict.txt',
+                'dict_path': 'utils/dict/ur_dict.txt',
                 
             },
             'rs_latin': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_rs_mobile.tar',
-                'dict_path': './utils/dict/rs_dict.txt',
+                'dict_path': 'utils/dict/rs_dict.txt',
                 
             },
             'oc': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_oc_mobile.tar',
-                'dict_path': './utils/dict/oc_dict.txt',
+                'dict_path': 'utils/dict/oc_dict.txt',
                 
             },
             'mr': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_mr_mobile.tar',
-                'dict_path': './utils/dict/mr_dict.txt',
+                'dict_path': 'utils/dict/mr_dict.txt',
                 
             },
             'ne': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ne_mobile.tar',
-                'dict_path': './utils/dict/ne_dict.txt',
+                'dict_path': 'utils/dict/ne_dict.txt',
                 
             },
             'rs_cyrillic': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_rsc_mobile.tar',
-                'dict_path': './utils/dict/rsc_dict.txt',
+                'dict_path': 'utils/dict/rsc_dict.txt',
                 
             },
             'bg': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_bg_mobile.tar',
-                'dict_path': './utils/dict/bg_dict.txt',
+                'dict_path': 'utils/dict/bg_dict.txt',
                 
             },
             'uk': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_uk_mobile.tar',
-                'dict_path': './utils/dict/uk_dict.txt',
+                'dict_path': 'utils/dict/uk_dict.txt',
                 
             },
             'be': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_be_mobile.tar',
-                'dict_path': './utils/dict/be_dict.txt',
+                'dict_path': 'utils/dict/be_dict.txt',
                 
             },
             'te': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_te_mobile.tar',
-                'dict_path': './utils/dict/te_dict.txt',
+                'dict_path': 'utils/dict/te_dict.txt',
                 
             },
             'kn': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ka_mobile.tar',
-                'dict_path': './utils/dict/ka_dict.txt',
+                'dict_path': 'utils/dict/ka_dict.txt',
                 
             },
             'ta': {
                 'url':
                 'https://docyard.s3.us-west-000.backblazeb2.com/UCR_models/torch_mobile/rec_ta_mobile.tar',
-                'dict_path': './utils/dict/ta_dict.txt',
+                'dict_path': 'utils/dict/ta_dict.txt',
                 
             }
         },
@@ -340,10 +340,10 @@ def parse_args(mMain=True, add_help=True):
         parser.add_argument(
             "--rec_char_dict_path",
             type=str,
-            default="./utils/dict/ench_dict.txt")
+            default="utils/dict/ench_dict.txt")
         parser.add_argument("--use_space_char", type=str2bool, default=True)
         parser.add_argument(
-            "--vis_font_path", type=str, default="./utils/fonts/only_en.ttf")
+            "--vis_font_path", type=str, default="utils/fonts/only_en.ttf")
         parser.add_argument("--drop_score", type=float, default=0.)
 
         # params for text classifier
@@ -363,10 +363,11 @@ def parse_args(mMain=True, add_help=True):
         parser.add_argument("--merge_add_margin", type=float, default=0.05)  
         
         parser.add_argument("--lang", type=str, default='ch_sim')
-        parser.add_argument("--model_type", type=str, default='torch_mobile')
+        parser.add_argument("--type", type=str, default='mobile')
+        parser.add_argument("--backend", type=str, default='torch')
         parser.add_argument("--det", type=str2bool, default=True)
         parser.add_argument("--rec", type=str2bool, default=True)
-        parser.add_argument("--use_angle_cls", type=str2bool, default=False)
+        parser.add_argument("--cls", type=str2bool, default=False)
                         
         return parser.parse_args()
     
@@ -412,7 +413,7 @@ def parse_args(mMain=True, add_help=True):
             label_list=['0', '180'],
             cls_batch_num=30,
             cls_thresh=0.9,
-            vis_font_path='./utils/fonts/only_en.ttf',
+            vis_font_path='utils/fonts/only_en.ttf',
             merge_boxes = False,
             merge_slope_thresh = 0.1, 
             merge_ycenter_thresh = 0.8, 
@@ -420,10 +421,11 @@ def parse_args(mMain=True, add_help=True):
             merge_width_thresh = 2.0,
             merge_add_margin = 0.05,
             lang='ch_sim',
-            model_type='torch_mobile',
+            type='mobile',
+            backend='torch',
             det=True,
             rec=True,
-            use_angle_cls=False)
+            cls=False)
 
 
 class UCR(predict_system.TextSystem):
@@ -435,12 +437,15 @@ class UCR(predict_system.TextSystem):
         """
         postprocess_params = parse_args(mMain=False, add_help=False)
         postprocess_params.__dict__.update(**kwargs)
-        self.use_angle_cls = postprocess_params.use_angle_cls
         lang = postprocess_params.lang
-        model_type = postprocess_params.model_type
+        type = postprocess_params.type
+        backend = postprocess_params.backend
+        model_type = backend + '_' + type
         det_algorithm = postprocess_params.det_algorithm
         rec_algorithm = postprocess_params.rec_algorithm
-        
+        self.det = postprocess_params.det
+        self.rec = postprocess_params.rec
+        self.cls = postprocess_params.cls
         if det_algorithm not in SUPPORT_DET_MODEL:
             logger.error('det_algorithm must in {}'.format(SUPPORT_DET_MODEL))
             sys.exit(0)
@@ -448,7 +453,7 @@ class UCR(predict_system.TextSystem):
             logger.error('rec_algorithm must in {}'.format(SUPPORT_MODEL))
             sys.exit(0)
         
-        assert model_type in SUPPORT_MODEL_TYPE, 'MODEL TYPE must be of {} format, but got {}'.format(
+        assert model_type in SUPPORT_MODEL_TYPE, 'TYPE_BACKEND must be of {} format, but got {}'.format(
                 SUPPORT_MODEL_TYPE, model_type)
 
             
@@ -481,9 +486,13 @@ class UCR(predict_system.TextSystem):
             postprocess_params.cls_model_location = cls_path
             postprocess_params.cls_config_location = cls_cfg_path
         
+        
+        postprocess_params.rec_char_dict_path = str(
+            Path(__file__).parent / postprocess_params.rec_char_dict_path)
+        
         super().__init__(postprocess_params)
 
-    def predict(self, img, det=True, rec=True):
+    def predict(self, img, det=None, rec=None, cls=None):
         """
         ocr with paddleocr
         args：
@@ -491,12 +500,17 @@ class UCR(predict_system.TextSystem):
             det: use text detection or not, if false, only rec will be exec. default is True
             rec: use text recognition or not, if false, only det will be exec. default is True
         """
+        if det==None:
+            det = self.det
+        if rec==None:
+            rec = self.rec
+        if cls==None:
+            cls = self.cls
         assert isinstance(img, (np.ndarray, list, str))
         if isinstance(img, list) and det == True:
             logger.error('When input a list of images, det must be false')
             exit(0)
 
-        self.use_angle_cls = self.use_angle_cls
         if isinstance(img, str):
             # download net image
             if img.startswith('http'):
@@ -524,7 +538,7 @@ class UCR(predict_system.TextSystem):
         else:
             if not isinstance(img, list):
                 img = [img]
-            if self.use_angle_cls:
+            if cls:
                 img, cls_res, elapse = self.text_classifier(img)
                 if not rec:
                     return cls_res
@@ -548,10 +562,10 @@ def main():
     ocr_engine = UCR(**(args.__dict__))
     for img_path in image_file_list:
         logger.info('{}{}{}'.format('*' * 10, img_path, '*' * 10))
-        result = ocr_engine.ocr(img_path,
+        result = ocr_engine.predict(img_path,
                                 det=args.det,
                                 rec=args.rec,
-                                cls=args.use_angle_cls)
+                                cls=args.cls)
         if result is not None:
             for line in result:
                 logger.info(line)
